@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.009000'; # VERSION
+our $VERSION = '0.009001'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Message';
@@ -15,7 +15,7 @@ with qw(
 use MooseX::Types::Moose       qw( ArrayRef );
 use MooseX::Types::CyberSource qw( PurchaseTotals Service Items );
 
-use Class::Load 0.20 qw( load_class );
+use Module::Runtime  qw( use_module );
 
 our @CARP_NOT = ( 'Class::MOP::Method::Wrapped', __PACKAGE__ );
 
@@ -35,7 +35,7 @@ sub add_item {
 			&& $args->isa( 'Business::CyberSource::RequestPart::Item' )
 		) {
 		$item
-			= load_class('Business::CyberSource::RequestPart::Item')
+			= use_module('Business::CyberSource::RequestPart::Item')
 			->new( $args )
 			;
 	}
@@ -48,7 +48,7 @@ sub add_item {
 }
 
 sub _build_service {
-	return load_class('Business::CyberSource::RequestPart::Service')->new;
+	return use_module('Business::CyberSource::RequestPart::Service')->new;
 }
 
 has comments => (
@@ -127,7 +127,7 @@ Business::CyberSource::Request - Abstract Request Class
 
 =head1 VERSION
 
-version 0.009000
+version 0.009001
 
 =head1 DESCRIPTION
 
